Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Rand ¶ added in v1.43.0
Rand returns a random subset of the input slice n based on the specified algorithm and number of elements (num). The algorithm parameter determines the randomization method to be used (e.g., STD, STDV2, FRAND, PG). If the input slice is nil, num <= 0, or num exceeds the length of n, the function will return nil.
Types ¶
Click to show internal directories.
Click to hide internal directories.